traefik

package
v0.0.8 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 27, 2026 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func EnsureNetwork

func EnsureNetwork(ctx context.Context, runner exec.Runner) error

EnsureNetwork creates the tug Docker network if it does not exist.

func EnsureRunning

func EnsureRunning(ctx context.Context, runner exec.Runner, cfg config.Traefik) error

EnsureRunning starts the tug-traefik container if it is not already running.

func Labels

func Labels(projectName, serviceName string, containerPort uint16) []string

Labels returns the Traefik Docker labels for an HTTP service. If containerPort > 0, a load-balancer server port label is included.

func NetworkName

func NetworkName() string

NetworkName returns the Docker network name used by tug.

func Stop added in v0.0.2

func Stop(ctx context.Context, runner exec.Runner) error

Stop removes the tug-traefik container and the tug network. It is idempotent — calling it when resources do not exist is not an error. Network removal failures are always ignored (other containers may be attached).

Types

This section is empty.

Jump to