Documentation
¶
Index ¶
- func EnsureNetwork(ctx context.Context, runner exec.Runner) error
- func EnsureRunning(ctx context.Context, runner exec.Runner, cfg config.Traefik) error
- func Labels(projectName, serviceName string, containerPort uint16) []string
- func NetworkName() string
- func Stop(ctx context.Context, runner exec.Runner) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func EnsureNetwork ¶
EnsureNetwork creates the tug Docker network if it does not exist.
func EnsureRunning ¶
EnsureRunning starts the tug-traefik container if it is not already running.
func Labels ¶
Labels returns the Traefik Docker labels for an HTTP service. If containerPort > 0, a load-balancer server port label is included.
func NetworkName ¶
func NetworkName() string
NetworkName returns the Docker network name used by tug.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.